"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BannerPlugin = void 0;
const base_1 = require("./base");
function getBannerCondition(condition) {
    if (typeof condition === "string") {
        return {
            type: "string",
            stringMatcher: condition
        };
    }
    if (condition instanceof RegExp) {
        return {
            type: "regexp",
            regexpMatcher: condition.source
        };
    }
    throw new Error("unreachable: condition should be one of string, RegExp");
}
function getBannerConditions(condition) {
    if (!condition)
        return undefined;
    if (Array.isArray(condition)) {
        return {
            type: "array",
            arrayMatcher: condition.map(i => getBannerCondition(i))
        };
    }
    return getBannerCondition(condition);
}
exports.BannerPlugin = (0, base_1.create)(base_1.BuiltinPluginKind.Banner, (bannerConfig) => {
    if (typeof bannerConfig === "string") {
        return {
            banner: bannerConfig
        };
    }
    return {
        ...bannerConfig,
        test: getBannerConditions(bannerConfig.test),
        include: getBannerConditions(bannerConfig.include),
        exclude: getBannerConditions(bannerConfig.exclude)
    };
});
