export { RspackBuiltinPlugin } from "./base";
export * from "./DefinePlugin";
export * from "./ProvidePlugin";
export * from "./BannerPlugin";
export * from "./ProgressPlugin";
export * from "./EntryPlugin";
export * from "./ExternalsPlugin";
export * from "./NodeTargetPlugin";
export * from "./ElectronTargetPlugin";
export * from "./HttpExternalsPlugin";
export * from "./HtmlPlugin";
export * from "./CopyPlugin";
export * from "./SwcJsMinimizerPlugin";
export * from "./SwcCssMinimizerPlugin";
import { RawDecoratorOptions, RawPresetEnv, RawProgressPluginConfig, RawReactOptions, RawRelayConfig, RawBuiltins, RawCssModulesConfig } from "@rspack/binding";
import { Compiler, RspackOptionsNormalized } from "..";
import { HtmlPluginOptions, SwcJsMinimizerPluginOptions, CopyPluginOptions, BannerPluginOptions } from ".";
type BuiltinsCssConfig = {
    modules?: Partial<RawCssModulesConfig>;
};
type EmotionConfigImportMap = {
    [packageName: string]: {
        [exportName: string]: {
            canonicalImport?: [string, string];
        };
    };
};
type EmotionConfig = {
    sourceMap?: boolean;
    autoLabel?: "never" | "dev-only" | "always";
    labelFormat?: string;
    importMap?: EmotionConfigImportMap;
};
type PluginImportConfig = {
    libraryName: string;
    libraryDirectory?: string;
    customName?: string;
    customStyleName?: string;
    style?: string | boolean;
    styleLibraryDirectory?: string;
    camelToDashComponentName?: boolean;
    transformToDefaultImport?: boolean;
    ignoreEsComponent?: Array<string>;
    ignoreStyleComponent?: Array<string>;
};
export interface Builtins {
    css?: BuiltinsCssConfig;
    treeShaking?: boolean | "module";
    progress?: boolean | RawProgressPluginConfig;
    react?: RawReactOptions;
    noEmitAssets?: boolean;
    define?: Record<string, string | boolean | undefined>;
    provide?: Record<string, string | string[]>;
    html?: Array<HtmlPluginOptions>;
    decorator?: boolean | Partial<RawDecoratorOptions>;
    minifyOptions?: SwcJsMinimizerPluginOptions;
    emotion?: boolean | EmotionConfig;
    presetEnv?: Partial<RawPresetEnv>;
    devFriendlySplitChunks?: boolean;
    copy?: CopyPluginOptions;
    banner?: BannerPluginOptions | BannerPluginOptions[];
    pluginImport?: PluginImportConfig[];
    relay?: boolean | RawRelayConfig;
}
export declare function deprecated_resolveBuiltins(builtins: Builtins, options: RspackOptionsNormalized, compiler: Compiler): RawBuiltins;
